package Log::Any::PT;
use Log::Any::Adapter::Core::Patch::UseDataDumperPerltidy;
our $VERSION = '0.01'; # VERSION
1;
# ABSTRACT: Shortcut for Log::Any::Adapter::Core::Patch::UseDataDumperPerltidy

__END__
=pod

=head1 NAME

Log::Any::PT - Shortcut for Log::Any::Adapter::Core::Patch::UseDataDumperPerltidy

=head1 VERSION

version 0.01

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

